==> huaweicloudsdkiotedge-3.1.58-py2.py3-none-any.whl: huaweicloudsdkiotedge/v2/model/create_install_cmd_request_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateInstallCmdRequestDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'host_tag': 'str'
    }

    attribute_map = {
        'host_tag': 'host_tag'
    }

    def __init__(self, host_tag=None):
        """CreateInstallCmdRequestDTO

        The model defined in huaweicloud sdk

        :param host_tag: 安装命令执行的主机标签DEFAULT|MASTER|SLAVE
        :type host_tag: str
        """
        
        

        self._host_tag = None
        self.discriminator = None

        if host_tag is not None:
            self.host_tag = host_tag

    @property
    def host_tag(self):
        """Gets the host_tag of this CreateInstallCmdRequestDTO.

        安装命令执行的主机标签DEFAULT|MASTER|SLAVE

        :return: The host_tag of this CreateInstallCmdRequestDTO.
        :rtype: str
        """
        return self._host_tag

    @host_tag.setter
    def host_tag(self, host_tag):
        """Sets the host_tag of this CreateInstallCmdRequestDTO.

        安装命令执行的主机标签DEFAULT|MASTER|SLAVE

        :param host_tag: The host_tag of this CreateInstallCmdRequestDTO.
        :type host_tag: str
        """
        self._host_tag = host_tag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstallCmdRequestDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotedge-3.1.151-py2.py3-none-any.whl: huaweicloudsdkiotedge/v2/model/create_install_cmd_request_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateInstallCmdRequestDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'host_tag': 'str'
    }

    attribute_map = {
        'host_tag': 'host_tag'
    }

    def __init__(self, host_tag=None):
        r"""CreateInstallCmdRequestDTO

        The model defined in huaweicloud sdk

        :param host_tag: 安装命令执行的主机标签DEFAULT|MASTER|SLAVE
        :type host_tag: str
        """
        
        

        self._host_tag = None
        self.discriminator = None

        if host_tag is not None:
            self.host_tag = host_tag

    @property
    def host_tag(self):
        r"""Gets the host_tag of this CreateInstallCmdRequestDTO.

        安装命令执行的主机标签DEFAULT|MASTER|SLAVE

        :return: The host_tag of this CreateInstallCmdRequestDTO.
        :rtype: str
        """
        return self._host_tag

    @host_tag.setter
    def host_tag(self, host_tag):
        r"""Sets the host_tag of this CreateInstallCmdRequestDTO.

        安装命令执行的主机标签DEFAULT|MASTER|SLAVE

        :param host_tag: The host_tag of this CreateInstallCmdRequestDTO.
        :type host_tag: str
        """
        self._host_tag = host_tag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstallCmdRequestDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
